==> ulyxex.0.1.0.with-tinyMce.zip: pages/code/admin_article_modify.php <==
<?php
class ArticleModify extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
        $this->tree = New Tree();
		$this->queryCommonSelect = 	" SELECT ".
										ARTICLES.".*,".
										USERS.".USERNAME,".USERS.".ID IDUSERID,".USERS.".USERLEVEL,".
										PAGES.".NAME,".PAGES.".ID PAGEID,".PAGES.".USERID USERPAGEID";
		$this->queryCommonFrom = 	" FROM ".
										ARTICLES.
										" INNER JOIN ".PAGES. " ON ".ARTICLES.".PAGEID = ".PAGES.".ID".
										" INNER JOIN ".USERS." ON ".ARTICLES.".USERID = ".USERS.".ID";
		$this->queryWhereArray = array();
	}
	public function art_params($artId) {
		$query = "SELECT ID,USERID,HIDE,PAGEID FROM ".ARTICLES." WHERE ID = ".$artId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
	public function update_article($artId) {
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		/* in case of no page created		*/
		$siteDat = $this->home_params();
		$content = $this->h->safe($_POST['content']);
		$pageId = isset($_POST['parent'])?$this->h->num($_POST['parent']):$siteDat['SANDBOXID'];
		$query = "UPDATE ".ARTICLES."  SET SUBJECT = '".$this->h->safe($_POST['subject'])."'".
										",USERID = ".$this->h->num($_POST['userid']);
		$query .= isset($_POST['updateDate'])?",DATE = '".$date."'":"";
		$query .=						",CONTENT = '".$content."'".
										",HIDE = ".$hide.
										",PAGEID = ".$pageId.
										" WHERE ID = ".$artId;
		$query = $this->q($query);
		$result = $this->h->h3("article ".strip_tags($_POST['subject'])." updated !");
		return $result;
	}
	public function data_article($artId) {
		$siteDat = $this->home_params();
		$query = $this->queryCommonSelect.$this->queryCommonFrom;
		switch ($_SESSION['level']) {
			case 1:
				// user level 1 can't edit others user level 1
				$this->queryWhereArray = array();
				if ($_SESSION['userid'] != 1) { // admin edit all
					$this->queryWhereArray[] = " (".USERS.".USERLEVEL > ".$_SESSION['level']." OR ".USERS.".ID = ".$_SESSION['userid'].")"; // all level 2, 3 and 4 user's articles, user's articles 
					$this->queryWhereArray[] = USERS.".ID != 1"; // but not admin articles
				}
				$this->queryWhereArray[] = ARTICLES.".ID = ".$artId;
				if (count($this->queryWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->queryWhereArray);
				break;
			case 2:
				$this->queryWhereArray = array();
				$this->queryWhereArray[] = "(".USERS.".ID = ".$_SESSION['userid']." OR ".PAGES.".USERID = ".$_SESSION['userid'].")"; // user's articles and articles in user's pages
				$this->queryWhereArray[] = USERS.".ID != 1"; // but not admin articles
				$this->queryWhereArray[] = ARTICLES.".ID = ".$artId;
				if (count($this->queryWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->queryWhereArray);
				break;
			case 3:
				$this->queryWhereArray = array();
				$this->queryWhereArray[] = ARTICLES.".USERID = ".$_SESSION['userid']; // user's articles only
				$this->queryWhereArray[] = ARTICLES.".ID = ".$artId;
				if (count($this->queryWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->queryWhereArray);
				break;
			case 4:
				$this->queryWhereArray = array();
				$this->queryWhereArray[] = ARTICLES.".USERID = ".$_SESSION['userid']; // user's articles only
				$this->queryWhereArray[] = ARTICLES.".ID = ".$artId;
				if (count($this->queryWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->queryWhereArray);
				break;
		}
// print $query.$this->h->br();
// print $this->h->print_rr($_SESSION);
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		if ($dat) {
			$content = $this->h->input("hidden","update",1);
			$content .= $this->h->input("hidden","art",$dat['ID']);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$content .= $this->h->p("(id:".$dat['ID'].")".$this->tr->wsb("hide").$this->h->input("checkbox","hide","on",$params));
			$content .= ($_SESSION['level'] < 4)?$this->h->p($this->tr->ws("choose page").$this->tree->pathsSelect($dat['PAGEID'])):$this->h->p("page: SandBox").$this->h->input("hidden","pageid",$siteDat['SANDBOXID']);
			$content .= $this->h->p($this->tr->w("subject (not displayed only info)")).$this->h->p($this->h->input("content","subject",htmlentities($dat['SUBJECT']),"size=".FIELDWIDTH));
			$content .= $this->h->p($this->tr->ws("content")).$this->h->p($this->h->textarea($dat['CONTENT'],"content",array(12,FIELDWIDTH)));
			$content .= $this->h->p($this->tr->ws("update date")."(".$dat['DATE'].")".$this->h->input("checkbox","updateDate","1"));
			$content .= $this->h->input("hidden","userid",$_SESSION['userid']);
			$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("update")));
			$result = $this->h->form($content,"article","post","admin.php?action=modify_article");
			return $result;
		}
	}
}
?>

==> ulyxex.0.1.1.with-tinyMce.zip: pages/code/admin_article_modify.php <==
<?php
class ArticleModify extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
        $this->tree = New Tree();
		$this->queryCommonSelect = 	" SELECT ".
										ARTICLES.".*,".
										USERS.".USERNAME,".USERS.".ID IDUSERID,".USERS.".USERLEVEL,".
										PAGES.".NAME,".PAGES.".ID PAGEID,".PAGES.".USERID USERPAGEID";
		$this->queryCommonFrom = 	" FROM ".
										ARTICLES.
										" INNER JOIN ".PAGES. " ON ".ARTICLES.".PAGEID = ".PAGES.".ID".
										" INNER JOIN ".USERS." ON ".ARTICLES.".USERID = ".USERS.".ID";
		$this->queryWhereArray = array();
	}
	public function art_params($artId) {
		$query = "SELECT ID,USERID,HIDE,PAGEID FROM ".ARTICLES." WHERE ID = ".$artId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
	public function update_article($artId) {
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		/* in case of no page created		*/
		$siteDat = $this->home_params();
		$content = $this->h->safe($_POST['content']);
		$pageId = isset($_POST['parent'])?$this->h->num($_POST['parent']):$siteDat['SANDBOXID'];
		$query = "UPDATE ".ARTICLES."  SET SUBJECT = '".$this->h->safe($_POST['subject'])."'".
										",USERID = ".$this->h->num($_POST['userid']);
		$query .= isset($_POST['updateDate'])?",DATE = '".$date."'":"";
		$query .=						",CONTENT = '".$content."'".
										",HIDE = ".$hide.
										",PAGEID = ".$pageId.
										" WHERE ID = ".$artId;
		$query = $this->q($query);
		$result = $this->h->h3("article ".strip_tags($_POST['subject'])." updated !");
		return $result;
	}
	public function data_article($artId) {
		$siteDat = $this->home_params();
		$query = $this->queryCommonSelect.$this->queryCommonFrom;
		switch ($_SESSION['level']) {
			case 1:
				// user level 1 can't edit others user level 1
				$this->queryWhereArray = array();
				if ($_SESSION['userid'] != 1) { // admin edit all
					$this->queryWhereArray[] = " (".USERS.".USERLEVEL > ".$_SESSION['level']." OR ".USERS.".ID = ".$_SESSION['userid'].")"; // all level 2, 3 and 4 user's articles, user's articles 
					$this->queryWhereArray[] = USERS.".ID != 1"; // but not admin articles
				}
				$this->queryWhereArray[] = ARTICLES.".ID = ".$artId;
				if (count($this->queryWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->queryWhereArray);
				break;
			case 2:
				$this->queryWhereArray = array();
				$this->queryWhereArray[] = "(".USERS.".ID = ".$_SESSION['userid']." OR ".PAGES.".USERID = ".$_SESSION['userid'].")"; // user's articles and articles in user's pages
				$this->queryWhereArray[] = USERS.".ID != 1"; // but not admin articles
				$this->queryWhereArray[] = ARTICLES.".ID = ".$artId;
				if (count($this->queryWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->queryWhereArray);
				break;
			case 3:
				$this->queryWhereArray = array();
				$this->queryWhereArray[] = ARTICLES.".USERID = ".$_SESSION['userid']; // user's articles only
				$this->queryWhereArray[] = ARTICLES.".ID = ".$artId;
				if (count($this->queryWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->queryWhereArray);
				break;
			case 4:
				$this->queryWhereArray = array();
				$this->queryWhereArray[] = ARTICLES.".USERID = ".$_SESSION['userid']; // user's articles only
				$this->queryWhereArray[] = ARTICLES.".ID = ".$artId;
				if (count($this->queryWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->queryWhereArray);
				break;
		}
// print $query.$this->h->br();
// print $this->h->print_rr($_SESSION);
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		if ($dat) {
			$content = $this->h->input("hidden","update",1);
			$content .= $this->h->input("hidden","art",$dat['ID']);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$content .= $this->h->p("(id:".$dat['ID'].")".$this->tr->wsb("hide").$this->h->input("checkbox","hide","on",$params));
			$content .= ($_SESSION['level'] < 4)?$this->h->p($this->tr->ws("choose page").$this->tree->pathsSelect($dat['PAGEID'])):$this->h->p("page: SandBox").$this->h->input("hidden","pageid",$siteDat['SANDBOXID']);
			$content .= $this->h->p($this->tr->w("subject (not displayed only info)")).$this->h->p($this->h->input("content","subject",htmlspecialchars($dat['SUBJECT'], ENT_QUOTES, "UTF-8"),"size=".FIELDWIDTH));
			$content .= $this->h->p($this->tr->ws("content")).$this->h->p($this->h->textarea($dat['CONTENT'],"content",array(12,FIELDWIDTH)));
			$content .= $this->h->p($this->tr->ws("update date")."(".$dat['DATE'].")".$this->h->input("checkbox","updateDate","1"));
			$content .= $this->h->input("hidden","userid",$_SESSION['userid']);
			$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("update")));
			$result = $this->h->form($content,"article","post","admin.php?action=modify_article");
			return $result;
		}
	}
}
?>
